Clusters cells based on their spatial coordinates using k-means or hierarchical clustering.
Usage
spatial_clusters(dt, k, method = c("kmeans", "hierarchical"))Clusters cells based on their spatial coordinates using k-means or hierarchical clustering.
spatial_clusters(dt, k, method = c("kmeans", "hierarchical"))